@@ -154,6 +154,10 @@ class RootController(TGController):
             'content':article.content
         }
 
+        hooks = config['hooks'].get('smallpress.before_edit_article', [])
+        for func in hooks:
+            func(article, value)
+
         return dict(article=article, value=value, blog=article.blog and article.blog.name or '',
                     form=get_article_form(), action=url(self.mount_point+'/save'),
                     upload_form=upload_form, upload_action=url(self.mount_point+'/attach'))
