@@ -1,4 +1,5 @@
-from tg import request
+import sys
+import tg
 from tw.forms import ListForm, TextField, TextArea, HiddenField, FileField
 from tw.core import WidgetsList
 from tw.forms.validators import UnicodeString, FieldStorageUploadConverter
@@ -34,4 +35,16 @@ class SearchForm(ListForm):
         text = TextField(suppress_label=True, validator=UnicodeString(not_empty=True),
                          attrs=dict(placeholder=l_('Search...')))
 
-    submit_text = 'Search'
\ No newline at end of file
+    submit_text = 'Search'
+
+def get_article_form():
+    config = tg.config['_smallpress']
+
+    article_form = config.get('form_instance')
+    if not article_form:
+        form_path = config.get('form', 'smallpress.lib.forms.ArticleForm')
+        root_module, path = form_path.split('.', 1)
+        form_class = reduce(getattr, path.split('.'), sys.modules[root_module])
+        article_form = config['form_instance'] = form_class()
+
+    return article_form
\ No newline at end of file
